This function is a wrapper for the reshape2::melt() function and splits column of Day, Operator, and Replicate information into 3 separate columns.
Usage
assayMelt(assay.df, exp.name)
Arguments
assay.df
Imported data.frame consisting of the following columns: 'ID','Lot', and columns identifying the Day, Operator and Replicate like so: 'D1_Op2_3' to indicate Day 1, operator 2, replicate 3.
exp.name
Experiment name (as a string). To be used to distinguish between experiments for when melted assays are combined using rbind().